==> smartgwtee-eval-5.1p.zip: com/smartgwt/client/widgets/form/PresetDateRangeItem.java <==
/*
 * Smart GWT (GWT for SmartClient)
 * Copyright 2008 and beyond, Isomorphic Software, Inc.
 *
 * Smart GWT is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version 3
 * as published by the Free Software Foundation.  Smart GWT is also
 * available under typical commercial license terms - see
 * http://smartclient.com/license
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 */
/* sgwtgen */
 
package com.smartgwt.client.widgets.form;


import com.smartgwt.client.event.*;
import com.smartgwt.client.core.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.events.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.callbacks.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.bean.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.events.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.tile.events.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.grid.events.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.layout.events.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.rte.*;
import com.smartgwt.client.widgets.rte.events.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.tree.events.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.calendar.events.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import com.google.gwt.user.client.ui.Widget;
import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.user.client.Element;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.google.gwt.event.shared.*;
import com.google.gwt.event.shared.HasHandlers;

/**
 * Allows the user to pick from pre-set date ranges or choose a custom date range via a {@link
 * com.smartgwt.client.widgets.DateRangeDialog}. <P> To use this item in the {@link
 * com.smartgwt.client.widgets.grid.ListGrid#getShowFilterEditor FilterEditor} or  {@link
 * com.smartgwt.client.widgets.form.FilterBuilder}, create a trivial  subclass which  defines {@link
 * com.smartgwt.client.widgets.form.PresetCriteriaItem#getOptions preset options}, then set {@link
 * com.smartgwt.client.widgets.grid.ListGridField#getFilterEditorType ListGridField.filterEditorType} to use this class
 * with the FilterEditor, or define a custom operator and set  Operator.editorType to use it with the FilterBuilder. <P>
 * See the @see <a href="http://www.smartclient.com/smartgwtee/showcase/#dateRangeFilterPresets" target="examples">Date
 * Range (Presets)</a> example for sample code.
 */
@BeanFactory.FrameworkClass
public class PresetDateRangeItem extends PresetCriteriaItem {

    public static PresetDateRangeItem getOrCreateRef(JavaScriptObject jsObj) {
        if(jsObj == null) return null;
        return new PresetDateRangeItem(jsObj);
    }


    public PresetDateRangeItem(){
        setAttribute("editorType", "PresetDateRangeItem");
    }

    public PresetDateRangeItem(JavaScriptObject jsObj){
        
        setJavaScriptObject(jsObj);
    }


    public PresetDateRangeItem(String name) {
        setName(name);
                setAttribute("editorType", "PresetDateRangeItem");
    }


    // ********************* Properties / Attributes ***********************

    // ********************* Methods ***********************

    // ********************* Static Methods ***********************

    // ***********************************************************

}

==> smartgwtee-eval-12.0p.zip: com/smartgwt/client/widgets/form/PresetDateRangeItem.java <==
/*
 * Smart GWT (GWT for SmartClient)
 * Copyright 2008 and beyond, Isomorphic Software, Inc.
 *
 * Smart GWT is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version 3
 * as published by the Free Software Foundation.  Smart GWT is also
 * available under typical commercial license terms - see
 * http://smartclient.com/license
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 */
/* sgwtgen */
 
package com.smartgwt.client.widgets.form;


import com.smartgwt.client.event.*;
import com.smartgwt.client.core.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.events.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.callbacks.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.bean.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.events.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.tile.events.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.grid.events.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.layout.events.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.rte.*;
import com.smartgwt.client.widgets.rte.events.*;
import com.smartgwt.client.widgets.ace.*;
import com.smartgwt.client.widgets.ace.events.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.tree.events.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.calendar.events.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import com.google.gwt.user.client.ui.Widget;
import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.user.client.Element;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.events.*;
import com.smartgwt.client.util.workflow.*;
import com.google.gwt.event.shared.*;
import com.google.gwt.event.shared.HasHandlers;

/**
 * Allows the user to pick from pre-set date ranges or choose a custom date range via a {@link
 * com.smartgwt.client.widgets.DateRangeDialog}. <P> To use this item in the {@link
 * com.smartgwt.client.widgets.grid.ListGrid#getShowFilterEditor FilterEditor} or  {@link
 * com.smartgwt.client.widgets.form.FilterBuilder}, create a trivial  subclass which  defines {@link
 * com.smartgwt.client.widgets.form.PresetCriteriaItem#getOptions preset options}, then set {@link
 * com.smartgwt.client.widgets.grid.ListGridField#getFilterEditorType ListGridField.filterEditorType} to use this class
 * with the FilterEditor, or define a custom operator and set {@link com.smartgwt.client.data.Operator#getEditorType
 * Operator.editorType} to use it with the FilterBuilder. <P> See the @see <a
 * href="http://www.smartclient.com/smartgwtee/showcase/#dateRangeFilterPresets" target="examples">Date Range (Presets)</a>
 * example for sample code.
 */
@BeanFactory.FrameworkClass
public class PresetDateRangeItem extends PresetCriteriaItem {

    public static PresetDateRangeItem getOrCreateRef(JavaScriptObject jsObj) {
        if(jsObj == null) return null;
        return new PresetDateRangeItem(jsObj);
    }
        


    public PresetDateRangeItem(){
        setAttribute("editorType", "PresetDateRangeItem");
    }

    public PresetDateRangeItem(JavaScriptObject jsObj){
        
        setJavaScriptObject(jsObj);
    }


    public PresetDateRangeItem(String name) {
        setName(name);
                setAttribute("editorType", "PresetDateRangeItem");
    }


    // ********************* Properties / Attributes ***********************

    // ********************* Methods ***********************

    // ********************* Static Methods ***********************

    // ***********************************************************

}
